Core Team
---------

* Matthew Carr (Core Developer)
* Jack Lovell (Developer)
* Alex Meakins (Architect/Core Developer)
* Matej Tomes (Developer)
* Vlad Neverov (Developer)


Contributors
------------

* Joseph Allcock
* Alfonso Baciero
* Corentin Bertrand
* Andrea Callarelli
* Ephrem Delabie
* Carine Giroud
* James Harrison
* Nick Hawkes
* Andy Meigs


Project History
---------------

Prior to the public release, large scale development was performed by the JET project team. Due to the inclusion of private intellectual property it was not possible to release the full development history of the code prior to the github release. For more information on the development of the code prior to this point, please contact the JET project.

